# Contributing

Contributions are very welcome!

Please run `make contrib` after cloning the repo if you'd like to contribute.
It does several things, mainly sets up the git pre-commit code linters.

